@@ -3,12 +3,12 @@ var searchData=
   ['waitforcompletion_0',['waitForCompletion',['../interfacecom_1_1sun_1_1star_1_1io_1_1XAsyncOutputMonitor.html#a361c72dc2296af9177a11f275daf6e10',1,'com::sun::star::io::XAsyncOutputMonitor']]],
   ['warning_1',['warning',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XErrorHandler.html#afbe534ab6b7be911323d58ce81a8761e',1,'com::sun::star::xml::sax::XErrorHandler']]],
   ['wasmodifiedsincelastsave_2',['wasModifiedSinceLastSave',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentRecovery.html#a7aabc985afdb6d0c4707d6e7bc28d855',1,'com::sun::star::document::XDocumentRecovery']]],
-  ['wasnull_3',['wasNull',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XColumn.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdb::XColumn::wasNull()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRow.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdbc::XRow::wasNull()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLInput.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdbc::XSQLInput::wasNull()']]],
-  ['windowactivated_4',['windowActivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XActivateListener.html#acb435a48c02120ba946e0135699699e1',1,'com::sun::star::awt::XActivateListener::windowActivated()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#acb435a48c02120ba946e0135699699e1',1,'com::sun::star::awt::XTopWindowListener::windowActivated()']]],
+  ['wasnull_3',['wasnull',['../interfacecom_1_1sun_1_1star_1_1sdb_1_1XColumn.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdb::XColumn::wasNull()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XRow.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdbc::XRow::wasNull()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLInput.html#a0d482c20564f9119052b1962f830190e',1,'com::sun::star::sdbc::XSQLInput::wasNull()']]],
+  ['windowactivated_4',['windowactivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XActivateListener.html#acb435a48c02120ba946e0135699699e1',1,'com::sun::star::awt::XActivateListener::windowActivated()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#acb435a48c02120ba946e0135699699e1',1,'com::sun::star::awt::XTopWindowListener::windowActivated()']]],
   ['windowadded_5',['windowAdded',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XVclContainerListener.html#a8b61696fc6270b034032a04a1538c66d',1,'com::sun::star::awt::XVclContainerListener']]],
   ['windowclosed_6',['windowClosed',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#ac73888b804c7a228c05c2273405e3e72',1,'com::sun::star::awt::XTopWindowListener']]],
   ['windowclosing_7',['windowClosing',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#a3541469431a2095b7d89d97f1b15da52',1,'com::sun::star::awt::XTopWindowListener']]],
-  ['windowdeactivated_8',['windowDeactivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XActivateListener.html#abed6be2aa04e809ac3f3c88aae736590',1,'com::sun::star::awt::XActivateListener::windowDeactivated()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#abed6be2aa04e809ac3f3c88aae736590',1,'com::sun::star::awt::XTopWindowListener::windowDeactivated()']]],
+  ['windowdeactivated_8',['windowdeactivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XActivateListener.html#abed6be2aa04e809ac3f3c88aae736590',1,'com::sun::star::awt::XActivateListener::windowDeactivated()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindowListener.html#abed6be2aa04e809ac3f3c88aae736590',1,'com::sun::star::awt::XTopWindowListener::windowDeactivated()']]],
   ['windowdisabled_9',['windowDisabled',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener2.html#a1d771b49bfc69bcccd58cb154597dc1e',1,'com::sun::star::awt::XWindowListener2']]],
   ['windowenabled_10',['windowEnabled',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener2.html#a3c2bacc1abd79207107ca4a3bf87e20e',1,'com::sun::star::awt::XWindowListener2']]],
   ['windowhidden_11',['windowHidden',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener.html#a1e41c8c0866972784adf459c93ebb272',1,'com::sun::star::awt::XWindowListener']]],
@@ -20,31 +20,31 @@ var searchData=
   ['windowremoved_17',['windowRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XVclContainerListener.html#a7cd022544ce1b835abf542b59a243fcd',1,'com::sun::star::awt::XVclContainerListener']]],
   ['windowresized_18',['windowResized',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener.html#a8ef405668e5b95952800561211a39b18',1,'com::sun::star::awt::XWindowListener']]],
   ['windowshown_19',['windowShown',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XWindowListener.html#a31b1c67bbeef4669864e845fa58bec8a',1,'com::sun::star::awt::XWindowListener']]],
-  ['write_20',['write',['../interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html#acf7872c58d7b19343a1c7837d73fb851',1,'com::sun::star::svg::XSVGWriter::write()'],['../interfacecom_1_1sun_1_1star_1_1connection_1_1XConnection.html#af5d0e860dcddad0778a00e469d80cd54',1,'com::sun::star::connection::XConnection::write()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XPersist.html#a050a43918745fbe95cd8fd61736d1740',1,'com::sun::star::io::XPersist::write()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XPersistObject.html#ab1a3fc9e022fba17ec1afbe55d2633df',1,'com::sun::star::io::XPersistObject::write()']]],
+  ['write_20',['write',['../interfacecom_1_1sun_1_1star_1_1connection_1_1XConnection.html#af5d0e860dcddad0778a00e469d80cd54',1,'com::sun::star::connection::XConnection::write()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XPersist.html#a050a43918745fbe95cd8fd61736d1740',1,'com::sun::star::io::XPersist::write()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XPersistObject.html#ab1a3fc9e022fba17ec1afbe55d2633df',1,'com::sun::star::io::XPersistObject::write()'],['../interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html#acf7872c58d7b19343a1c7837d73fb851',1,'com::sun::star::svg::XSVGWriter::write()']]],
   ['writeandattachtostream_21',['writeAndAttachToStream',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XOptimizedStorage.html#afa26d28cbc4429a8d00ac19163a65e42',1,'com::sun::star::embed::XOptimizedStorage']]],
   ['writearray_22',['writeArray',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#ae6a450f5a29a23f54d07cc03509dc471',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writebinarystream_23',['writeBinaryStream',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#ae5b3780fe34b190da72341ce04701cd9',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writeblob_24',['writeBlob',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a0a8fe20e1025a5046e4b5002f598058a',1,'com::sun::star::sdbc::XSQLOutput']]],
-  ['writeboolean_25',['writeBoolean',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a5cbfe751c372d3439b4ef0d04d22bddf',1,'com::sun::star::sdbc::XSQLOutput::writeBoolean()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a974ea51ab41eda2a28759f98db01654d',1,'com::sun::star::io::XDataOutputStream::writeBoolean()']]],
-  ['writebyte_26',['writeByte',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#aef122d84bce7554991afdfe6002a8a60',1,'com::sun::star::sdbc::XSQLOutput::writeByte()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a6f61418e64fa415453c816121e1c4bf0',1,'com::sun::star::io::XDataOutputStream::writeByte()']]],
-  ['writebytes_27',['writeBytes',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a52241bd7fee8ac764ec58a3fd1ce4bb0',1,'com::sun::star::sdbc::XSQLOutput::writeBytes()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XOutputStream.html#a113fb0faff995a205e700e9098404aed',1,'com::sun::star::io::XOutputStream::writeBytes()']]],
+  ['writeboolean_25',['writeboolean',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a974ea51ab41eda2a28759f98db01654d',1,'com::sun::star::io::XDataOutputStream::writeBoolean()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a5cbfe751c372d3439b4ef0d04d22bddf',1,'com::sun::star::sdbc::XSQLOutput::writeBoolean()']]],
+  ['writebyte_26',['writebyte',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a6f61418e64fa415453c816121e1c4bf0',1,'com::sun::star::io::XDataOutputStream::writeByte()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#aef122d84bce7554991afdfe6002a8a60',1,'com::sun::star::sdbc::XSQLOutput::writeByte()']]],
+  ['writebytes_27',['writebytes',['../interfacecom_1_1sun_1_1star_1_1io_1_1XOutputStream.html#a113fb0faff995a205e700e9098404aed',1,'com::sun::star::io::XOutputStream::writeBytes()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a52241bd7fee8ac764ec58a3fd1ce4bb0',1,'com::sun::star::sdbc::XSQLOutput::writeBytes()']]],
   ['writechar_28',['writeChar',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#ab90e273f87ec3951a0ed67a70d66b597',1,'com::sun::star::io::XDataOutputStream']]],
   ['writecharacterstream_29',['writeCharacterStream',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#ad36aa8cbf046406d762bd45986453912',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writeclob_30',['writeClob',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a59d43ed60b0be452b3994a5337821ddd',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writedate_31',['writeDate',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#afee91017c0121cfacef3a668de4ea66e',1,'com::sun::star::sdbc::XSQLOutput']]],
-  ['writedouble_32',['writeDouble',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a04bd14640b17ea229cf7b9c207ec67cc',1,'com::sun::star::sdbc::XSQLOutput::writeDouble()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#aabc69d3ec1c496fb00b21e77cfe82302',1,'com::sun::star::io::XDataOutputStream::writeDouble()']]],
+  ['writedouble_32',['writedouble',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#aabc69d3ec1c496fb00b21e77cfe82302',1,'com::sun::star::io::XDataOutputStream::writeDouble()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a04bd14640b17ea229cf7b9c207ec67cc',1,'com::sun::star::sdbc::XSQLOutput::writeDouble()']]],
   ['writefile_33',['writeFile',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XSimpleFileAccess2.html#a6d3ef0a71067b5b3eb5b788f787c179a',1,'com::sun::star::ucb::XSimpleFileAccess2']]],
-  ['writefloat_34',['writeFloat',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#abfe7c0d71e0fefaf1e0f4e1e03b1c301',1,'com::sun::star::sdbc::XSQLOutput::writeFloat()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a9b70a698e4862a9c77f5bac1ee8f6e9c',1,'com::sun::star::io::XDataOutputStream::writeFloat([in] float Value)']]],
+  ['writefloat_34',['writefloat',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a9b70a698e4862a9c77f5bac1ee8f6e9c',1,'com::sun::star::io::XDataOutputStream::writeFloat()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#abfe7c0d71e0fefaf1e0f4e1e03b1c301',1,'com::sun::star::sdbc::XSQLOutput::writeFloat()']]],
   ['writehyper_35',['writeHyper',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#afb8c2fdcd76be39dfad00301f64c44f1',1,'com::sun::star::io::XDataOutputStream']]],
   ['writeint_36',['writeInt',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a9c29d5a0dfa647e799a7581c4943cfec',1,'com::sun::star::sdbc::XSQLOutput']]],
-  ['writelong_37',['writeLong',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a71c389f15d5920cfc814d22ff2c4c8c7',1,'com::sun::star::sdbc::XSQLOutput::writeLong()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a1d26480b2739da2a883d18d81a010cca',1,'com::sun::star::io::XDataOutputStream::writeLong()']]],
+  ['writelong_37',['writelong',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#a1d26480b2739da2a883d18d81a010cca',1,'com::sun::star::io::XDataOutputStream::writeLong()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a71c389f15d5920cfc814d22ff2c4c8c7',1,'com::sun::star::sdbc::XSQLOutput::writeLong()']]],
   ['writemanifestsequence_38',['writeManifestSequence',['../interfacecom_1_1sun_1_1star_1_1packages_1_1manifest_1_1XManifestWriter.html#ace27b273cc1cd509fe0ac35f85819690',1,'com::sun::star::packages::manifest::XManifestWriter']]],
-  ['writeobject_39',['writeObject',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a16bf7b5965690326ff155a4b4a41f8f5',1,'com::sun::star::sdbc::XSQLOutput::writeObject()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XObjectOutputStream.html#a958294adf8cb9322ba582142adfb3262',1,'com::sun::star::io::XObjectOutputStream::writeObject()']]],
+  ['writeobject_39',['writeobject',['../interfacecom_1_1sun_1_1star_1_1io_1_1XObjectOutputStream.html#a958294adf8cb9322ba582142adfb3262',1,'com::sun::star::io::XObjectOutputStream::writeObject()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a16bf7b5965690326ff155a4b4a41f8f5',1,'com::sun::star::sdbc::XSQLOutput::writeObject([in]XSQLData x)']]],
   ['writeref_40',['writeRef',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a61711063e5e9c6570a9b91058256c00f',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writeregistryinfo_41',['writeRegistryInfo',['../interfacecom_1_1sun_1_1star_1_1loader_1_1XImplementationLoader.html#a26c61eb704f327062a514cba529a53c8',1,'com::sun::star::loader::XImplementationLoader']]],
-  ['writeshort_42',['writeShort',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#ad7fc896888a1924698cec1d713e8672f',1,'com::sun::star::sdbc::XSQLOutput::writeShort()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#ab376bce9addf0bad8c24af5b54e9736b',1,'com::sun::star::io::XDataOutputStream::writeShort()']]],
+  ['writeshort_42',['writeshort',['../interfacecom_1_1sun_1_1star_1_1io_1_1XDataOutputStream.html#ab376bce9addf0bad8c24af5b54e9736b',1,'com::sun::star::io::XDataOutputStream::writeShort()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#ad7fc896888a1924698cec1d713e8672f',1,'com::sun::star::sdbc::XSQLOutput::writeShort()']]],
   ['writesql_43',['writeSQL',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLData.html#afc87b5956a512cb79b23c8ea4ac037eb',1,'com::sun::star::sdbc::XSQLData']]],
-  ['writestring_44',['writeString',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#aad7cf4ad6f3e43fd4b89b79e92b5fccb',1,'com::sun::star::sdbc::XSQLOutput::writeString()'],['../interfacecom_1_1sun_1_1star_1_1io_1_1XTextOutputStream.html#a79d9a3c7200a71f842f8061ed63df222',1,'com::sun::star::io::XTextOutputStream::writeString()']]],
+  ['writestring_44',['writestring',['../interfacecom_1_1sun_1_1star_1_1io_1_1XTextOutputStream.html#a79d9a3c7200a71f842f8061ed63df222',1,'com::sun::star::io::XTextOutputStream::writeString()'],['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#aad7cf4ad6f3e43fd4b89b79e92b5fccb',1,'com::sun::star::sdbc::XSQLOutput::writeString([in]string x)']]],
   ['writestruct_45',['writeStruct',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a6fb157f81ad170c36391f8a4e491e1c4',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writetime_46',['writeTime',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a7eee224b0a4330ce0118343d0ba4bb4d',1,'com::sun::star::sdbc::XSQLOutput']]],
   ['writetimestamp_47',['writeTimestamp',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XSQLOutput.html#a31b0ed29b640e29a55a025c039039c16',1,'com::sun::star::sdbc::XSQLOutput']]],
